@@ -30,9 +30,9 @@ import com.openexchange.mobile.configuration.generator.configuration.MobileConfi
 import com.openexchange.mobile.configuration.generator.configuration.Property;
 import com.openexchange.mobile.configuration.generator.osgi.Activator;
 import com.openexchange.mobile.configuration.generator.services.MobileConfigServiceRegistry;
-import com.openexchange.templating.OXTemplate;
-import com.openexchange.templating.TemplateException;
-import com.openexchange.templating.TemplateService;
+import com.openexchange.templating.base.OXTemplate;
+import com.openexchange.templating.base.TemplateException;
+import com.openexchange.templating.base.TemplateService;
 import com.openexchange.tools.servlet.http.Tools;
 
 
@@ -88,7 +88,7 @@ public class MobileConfigServlet extends HttpServlet {
         
     }
 
-    private static final transient Log LOG = LogFactory.getLog(MobileConfigServlet.class);
+    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MobileConfigServlet.class));
 
     /**
      * 
@@ -142,6 +142,8 @@ public class MobileConfigServlet extends HttpServlet {
         CabUtil.writeCabFile(new DataOutputStream(new BufferedOutputStream(out)), write(email, host, username, domain));
     }
 
+    private static final Pattern PATTERN_CRLF = Pattern.compile("\r?\n|(?:%0[aA])?%0[dD]");
+
     @Override
     public void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
         resp.setCharacterEncoding("UTF-8");
@@ -194,11 +196,11 @@ public class MobileConfigServlet extends HttpServlet {
             if (null != header) {
                 if (header.matches(iphoneRegEx)) {
                     // iPhone part
-                    resp.sendRedirect(Activator.ALIAS + "/eas.mobileconfig?l=" + URLEncoder.encode(login,"UTF-8") + mailpart);
+                    resp.sendRedirect(Activator.ALIAS + "/eas.mobileconfig?l=" + PATTERN_CRLF.matcher(URLEncoder.encode(login,"UTF-8")).replaceAll("") + mailpart);
                     return;
                 } else if (header.matches(winMobRegEx)) {
                     // WinMob part
-                    resp.sendRedirect(Activator.ALIAS + "/ms.cab?l=" + URLEncoder.encode(login,"UTF-8") + mailpart);
+                    resp.sendRedirect(Activator.ALIAS + "/ms.cab?l=" + PATTERN_CRLF.matcher(URLEncoder.encode(login,"UTF-8")).replaceAll("") + mailpart);
                     return;
                 } else {
                     printError(req, resp, ErrorMessage.MSG_NO_SUPPORTED_DEVICE_FOUND);
@@ -289,7 +291,7 @@ public class MobileConfigServlet extends HttpServlet {
             } else if (Locale.GERMAN.equals(locale)) {
                 writer.println("<h1>" + "Geben Sie für die automatische Konfiguration Ihres Gerätes Ihren Benutzernamen ein." + "</h1>");
             }
-            writer.println("<input name=\"" + PARAMETER_LOGIN +"\" type=\"text\" size=\"30\" maxlength=\"30\">");
+            writer.println("<input name=\"" + PARAMETER_LOGIN +"\" type=\"text\" size=\"30\" maxlength=\"100\">");
             writer.println("<input type=\"submit\" value=\" Absenden \">");
             writer.println("</td>");
             writer.println("</tr>");
@@ -311,9 +313,9 @@ public class MobileConfigServlet extends HttpServlet {
             writer.println("<table>");
             writer.println("<tr>");
             if (Locale.ENGLISH.equals(locale)) {
-                writer.println("<td><h1>" + String.valueOf(msg.getGerman()) + "</h1></td>");
-            } else if (Locale.GERMAN.equals(locale)) {
                 writer.println("<td><h1>" + String.valueOf(msg.getEnglish()) + "</h1></td>");
+            } else if (Locale.GERMAN.equals(locale)) {
+                writer.println("<td><h1>" + String.valueOf(msg.getGerman()) + "</h1></td>");
             }
             writer.println("</tr>");
             writer.println("</table>");
@@ -361,7 +363,7 @@ public class MobileConfigServlet extends HttpServlet {
     }
 
     private void printError(HttpServletRequest req, final HttpServletResponse resp, final ErrorMessage string) throws IOException {
-        resp.sendRedirect(Activator.ALIAS + "?error=" + URLEncoder.encode(String.valueOf(string.ordinal()),"UTF-8"));
+        resp.sendRedirect(Activator.ALIAS + "?error=" + Integer.toString(string.ordinal()));
     }
 
     private void writeMobileConfig(final PrintWriter printWriter, OutputStream outStream, final String email, final String host, final String username, final String domain) throws IOException, TemplateException, ConfigurationException {
